require "numru/advanceddcl"

include NumRu::AdvancedDCL

Dev.open("X")
Frame.set("lfull", true)
Frame.mgn(0.0, 0.0, 0.08, 0.08)

Frame.rat(1.0, 0.6)
Frame.settitle("FIGURE TITLE", "T", 0.0, -1.0, 0.02, 1)
Frame.settitle("page: #PAGE", "B", 1.0, 1.0, 0.02, 2)
Frame.settitle("PROG.NAME", "B", -1.0, 1.0, 0.02, 3)

Frame.new
Fig.set("window", [0.0, 1.0, 0.0, 1.0])
Fig.pwwr(1)
Text.vdraw(0.01, 0.02, "LOWER LEFT", {"charsize"=>0.02, "charrot"=>0, "charcent"=>-1, "charindex"=>3})
Text.vdraw(0.01, 0.58, "UPPER LEFT", {"charsize"=>0.02, "charrot"=>0, "charcent"=>-1, "charindex"=>3})
Text.vdraw(0.99, 0.02, "LOWER RIGHT", {"charsize"=>0.02, "charrot"=>0, "charcent"=>1, "charindex"=>3})
Text.vdraw(0.99, 0.58, "UPPER RIGHT", {"charsize"=>0.02, "charrot"=>0, "charcent"=>1, "charindex"=>3})

Dev.close
